summaryrefslogtreecommitdiff
path: root/dev/tsunami.hh
diff options
context:
space:
mode:
Diffstat (limited to 'dev/tsunami.hh')
-rw-r--r--dev/tsunami.hh6
1 files changed, 3 insertions, 3 deletions
diff --git a/dev/tsunami.hh b/dev/tsunami.hh
index bcbd9c756..3c304dccd 100644
--- a/dev/tsunami.hh
+++ b/dev/tsunami.hh
@@ -37,7 +37,7 @@
#include "dev/platform.hh"
-class AdaptecController;
+class IdeController;
class TlaserClock;
class EtherDev;
class TsunamiCChip;
@@ -64,8 +64,8 @@ class Tsunami : public Platform
System *system;
/** Pointer to the TsunamiIO device which has the RTC */
TsunamiIO *io;
- /** Pointer to the SCSI controller device */
- AdaptecController *scsi;
+ /** Pointer to the disk controller device */
+ IdeController *disk_controller;
/** Pointer to the ethernet controller device */
EtherDev *ethernet;